package test;

/**
 * Copyright Hyoung Sook Kim.
 * Created on 2002. 10. 9.
 */
//package oz.dw.mail;
import javax.mail.Message;
import javax.mail.Address;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.Multipart;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeUtility;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMultipart;
import javax.mail.MessagingException;
import java.io.UnsupportedEncodingException;
import java.util.Properties;
import java.util.Date;

/**
 * @author Hyoung Sook Kim (oz4me@hanmail.net)
 */
public class Email {
	private MimeMessage msg = null;
	private Address from = null;
	private Address[] recipients = null;
	private Session session = null;
	
	/**
	 * Constructor for EMail.
	 */
	public Email(String host, boolean debug) {
		// create some properties and get the default Session
		Properties props = new Properties();
		props.put("mail.smtp.host", host);
		if (debug) props.put("mail.debug", "" + debug);
	
		Session session = Session.getDefaultInstance(props, null);
		session.setDebug(debug);
		msg = new MimeMessage(session);
	}
	
	/**
	 *  ̸ ּҵ鸦  Ѵ. RecipientType  BCC, CC, To  ִ.
	 * @param type Message.RecipientType
	 * @paramrecipients java.lang.String[]
	 */
	private void setRecipients(Message.RecipientType type, String[] recipients)
		throws MessagingException {
		InternetAddress[] users = new InternetAddress[recipients.length];
		for (int i = 0; i < recipients.length; i++) {
			users[i] = new InternetAddress(recipients[i]);
		}
		msg.setRecipients(type, users);
	}
	
	/**
	 *  ̸ ּҸ  Ѵ. RecipientType  BCC, CC, To  ִ.
	 * @param type Message.RecipientType
	 * @param recipient java.lang.String
	 */
	private void setRecipient(Message.RecipientType type, String recipient)
		throws  MessagingException{
		InternetAddress user = new InternetAddress(recipient);
		msg.setRecipient(type, user);
	}
	
	/**
	 *  ̸ ּҸ  Ѵ. RecipientType  BCC, CC, To  ִ.
	 * @param type Message.RecipientType
	 * @param recipient java.lang.String ̸ ּ
	 * @param personal java.lang.String ̸ ּ ̸
	 */
	private void setRecipient(Message.RecipientType type, String recipient, 
		String personal)
		throws  MessagingException{
		InternetAddress user = null;
		try {
			personal = MimeUtility.encodeText(personal, "utf-8", "B");
			user =  new InternetAddress(recipient, personal);
		}
		catch (UnsupportedEncodingException uee) {
			user = new InternetAddress(recipient);
		}
		msg.setRecipient(type, user);
	}

	/**
	 *  ̸ ּҸ  Ѵ. RecipientType  BCC, CC, To  ִ.
	 * @param type Message.RecipientType
	 * @param recipient java.lang.String[] ̸ ּҵ
	 * @param personal java.lang.String[] ̸ ּ ̸
	 */
	private void setRecipients(Message.RecipientType type, String[] recipients,
		String[] personals)
		throws MessagingException {
		InternetAddress[] users = new InternetAddress[recipients.length];

		for (int i = 0; i < recipients.length; i++) {
			try {
			personals[i] = MimeUtility.encodeText(personals[i], "utf-8", "B");;
			users[i] = new InternetAddress(recipients[i], personals[i]);
			} 
			catch (UnsupportedEncodingException uee) {
				users[i] = new InternetAddress(recipients[i]);
			}
		}
		msg.setRecipients(type, users);
	}
	
	public void setFrom(String from) throws MessagingException {
		msg.setFrom(new InternetAddress(from));
	}
	
	public void setFrom(String from, String name) throws MessagingException {
		InternetAddress user = null;
		try {
			name = MimeUtility.encodeText(name, "utf-8", "B");
			user =  new InternetAddress(from, name);
			msg.setFrom(new InternetAddress(from, name));
		}
		catch (UnsupportedEncodingException uee) {
			user = new InternetAddress(from);
			msg.setFrom(new InternetAddress(from));
		}
	}
	
	public void setTo(String to) throws MessagingException {
		setRecipient(Message.RecipientType.TO, to);
	}
	
	public void setTo(String to[]) throws MessagingException {
		setRecipients(Message.RecipientType.TO, to);
	}
	
	public void setTo(String to, String personname) 
		throws MessagingException {
		setRecipient(Message.RecipientType.TO, to, personname);
	}	
	
	public void setTo(String to[], String personname[]) 
		throws MessagingException {
		setRecipients(Message.RecipientType.TO, to, personname);
	}	
	
	public void setCc(String cc) throws MessagingException {
		setRecipient(Message.RecipientType.CC, cc);
	}
	
	public void setCc(String cc[]) throws MessagingException {
		setRecipients(Message.RecipientType.CC, cc);
	}
	
	public void setCc(String cc[], String personname[]) 
		throws MessagingException {
		setRecipients(Message.RecipientType.CC, cc, personname);
	}	
	
	public void setBCc(String bcc) throws MessagingException {
		setRecipient(Message.RecipientType.BCC, bcc);
	}
	
	public void setBcc(String bcc[]) throws MessagingException {
		setRecipients(Message.RecipientType.BCC, bcc);
	}
	
	public void setBcc(String bcc[], String personname[]) 
		throws MessagingException {
		setRecipients(Message.RecipientType.BCC, bcc, personname);
	}
	
	public void setSubject(String subject) throws MessagingException{
	    try {
		    subject = MimeUtility.encodeText(subject, "utf-8", "B");
	    } 
	    catch (UnsupportedEncodingException e) {
	    	throw new MessagingException(e.getMessage());
	    }
		msg.setSubject(subject);
	}
	
	public void send() throws MessagingException {
		msg.setSentDate(new Date());
		Transport.send(msg);
	}
	
	public void setAlternativeContents(String msgText, String htmlText)
		throws MessagingException {
	    // create and fill the first message part
	    MimeBodyPart mbp1 = new MimeBodyPart();
	    mbp1.setContent(msgText, "text/plain; charset=utf-8");
	    
	    // create and fill the second message part
	    MimeBodyPart mbp2 = new MimeBodyPart();
	    // Use setText(text, charset), to show it off !
	    mbp2.setContent(htmlText, "text/html; charset=utf-8");
	    
	    // create the Multipart and its parts to it
	    MimeMultipart mp = new MimeMultipart();
	    mp.addBodyPart(mbp1);
	    mp.addBodyPart(mbp2);
	    mp.setSubType("alternative");
	    
	    // add the Multipart to the message
	    msg.setContent(mp);
	}
	
	public void setContent(Object o, java.lang.String type) 
		throws MessagingException {
		msg.setContent(o, type);
	}
	
	public void setText(String msgText) throws MessagingException {
		msg.setText(msgText, "utf-8");
	}
	
	public void setHtml(String msgHtml) throws MessagingException {
		msg.setContent(msgHtml, "text/html; charset=utf-8");
	}
	
	public void setContent(Multipart mp) 
		throws MessagingException {
		msg.setContent(mp);
	}
}